@@ -3,7 +3,6 @@ require 'forwardable'
 require 'ostruct'
 
 module JIRA
-
   # This class is the main access point for all JIRA::Resource instances.
   #
   # The client must be initialized with an options hash containing
@@ -26,13 +25,13 @@ module JIRA
   #   :auth_type          => :oauth,
   #   :proxy_address      => nil,
   #   :proxy_port         => nil,
-  #   :additional_cookies => nil
+  #   :additional_cookies => nil,
+  #   :default_headers    => {}
   #
   # See the JIRA::Base class methods for all of the available methods on these accessor
   # objects.
 
   class Client
-
     extend Forwardable
 
     # The OAuth::Consumer instance returned by the OauthClient
@@ -47,17 +46,18 @@ module JIRA
     def_delegators :@request_client, :init_access_token, :set_access_token, :set_request_token, :request_token, :access_token, :authenticated?
 
     DEFAULT_OPTIONS = {
-      :site               => 'http://localhost:2990',
-      :context_path       => '/jira',
-      :rest_base_path     => "/rest/api/2",
-      :ssl_verify_mode    => OpenSSL::SSL::VERIFY_PEER,
-      :use_ssl            => true,
-      :use_client_cert    => false,
-      :auth_type          => :oauth,
-      :http_debug         => false
-    }
+      site: 'http://localhost:2990',
+      context_path: '/jira',
+      rest_base_path: '/rest/api/2',
+      ssl_verify_mode: OpenSSL::SSL::VERIFY_PEER,
+      use_ssl: true,
+      use_client_cert: false,
+      auth_type: :oauth,
+      http_debug: false,
+      default_headers: {}
+    }.freeze
 
-    def initialize(options={})
+    def initialize(options = {})
       options = DEFAULT_OPTIONS.merge(options)
       @options = options
       @options[:rest_base_path] = @options[:context_path] + @options[:rest_base_path]
@@ -73,6 +73,8 @@ module JIRA
       when :oauth, :oauth_2legged
         @request_client = OauthClient.new(@options)
         @consumer = @request_client.consumer
+      when :jwt
+        @request_client = JwtClient.new(@options)
       when :basic
         @request_client = HttpClient.new(@options)
       when :cookie
@@ -153,10 +155,22 @@ module JIRA
       JIRA::Resource::FieldFactory.new(self)
     end
 
+    def Board
+      JIRA::Resource::BoardFactory.new(self)
+    end
+
     def RapidView
       JIRA::Resource::RapidViewFactory.new(self)
     end
 
+    def Sprint
+      JIRA::Resource::SprintFactory.new(self)
+    end
+
+    def SprintReport
+      JIRA::Resource::SprintReportFactory.new(self)
+    end
+
     def ServerInfo
       JIRA::Resource::ServerInfoFactory.new(self)
     end
@@ -212,27 +226,26 @@ module JIRA
 
     # HTTP methods with a body
     def post(path, body = '', headers = {})
-      headers = {'Content-Type' => 'application/json'}.merge(headers)
+      headers = { 'Content-Type' => 'application/json' }.merge(headers)
       request(:post, path, body, merge_default_headers(headers))
     end
 
     def put(path, body = '', headers = {})
-      headers = {'Content-Type' => 'application/json'}.merge(headers)
+      headers = { 'Content-Type' => 'application/json' }.merge(headers)
       request(:put, path, body, merge_default_headers(headers))
     end
 
     # Sends the specified HTTP request to the REST API through the
     # appropriate method (oauth, basic).
-    def request(http_method, path, body = '', headers={})
+    def request(http_method, path, body = '', headers = {})
       puts "#{http_method}: #{path} - [#{body}]" if @http_debug
       @request_client.request(http_method, path, body, headers)
     end
 
     protected
 
-      def merge_default_headers(headers)
-        {'Accept' => 'application/json'}.merge(headers)
-      end
-
+    def merge_default_headers(headers)
+      { 'Accept' => 'application/json' }.merge(@options[:default_headers]).merge(headers)
+    end
   end
 end
