@@ -4,22 +4,21 @@ require 'forwardable'
 
 module JIRA
   class OauthClient < RequestClient
-
     DEFAULT_OPTIONS = {
-      :signature_method   => 'RSA-SHA1',
-      :request_token_path => "/plugins/servlet/oauth/request-token",
-      :authorize_path     => "/plugins/servlet/oauth/authorize",
-      :access_token_path  => "/plugins/servlet/oauth/access-token",
-      :private_key_file   => "rsakey.pem",
-      :consumer_key       => nil,
-      :consumer_secret    => nil
-    }
+      signature_method: 'RSA-SHA1',
+      request_token_path: '/plugins/servlet/oauth/request-token',
+      authorize_path: '/plugins/servlet/oauth/authorize',
+      access_token_path: '/plugins/servlet/oauth/access-token',
+      private_key_file: 'rsakey.pem',
+      consumer_key: nil,
+      consumer_secret: nil
+    }.freeze
 
     # This exception is thrown when the client is used before the OAuth access token
     # has been initialized.
     class UninitializedAccessTokenError < StandardError
       def message
-        "init_access_token must be called before using the client"
+        'init_access_token must be called before using the client'
       end
     end
 
@@ -35,11 +34,11 @@ module JIRA
       @consumer = init_oauth_consumer(@options)
     end
 
-    def init_oauth_consumer(options)
+    def init_oauth_consumer(_options)
       @options[:request_token_path] = @options[:context_path] + @options[:request_token_path]
       @options[:authorize_path] = @options[:context_path] + @options[:authorize_path]
       @options[:access_token_path] = @options[:context_path] + @options[:access_token_path]
-      OAuth::Consumer.new(@options[:consumer_key],@options[:consumer_secret],@options)
+      OAuth::Consumer.new(@options[:consumer_key], @options[:consumer_secret], @options)
     end
 
     # Returns the current request token if it is set, else it creates
@@ -69,20 +68,20 @@ module JIRA
     # Returns the current access token. Raises an
     # JIRA::Client::UninitializedAccessTokenError exception if it is not set.
     def access_token
-      raise UninitializedAccessTokenError.new unless @access_token
+      raise UninitializedAccessTokenError unless @access_token
       @access_token
     end
 
-    def make_request(http_method, path, body='', headers={})
+    def make_request(http_method, path, body = '', headers = {})
       # When using oauth_2legged we need to add an empty oauth_token parameter to every request.
       if @options[:auth_type] == :oauth_2legged
-        oauth_params_str = "oauth_token="
+        oauth_params_str = 'oauth_token='
         uri = URI.parse(path)
-        if uri.query.to_s == ""
-          uri.query = oauth_params_str
-        else
-          uri.query = uri.query + "&" + oauth_params_str
-        end
+        uri.query = if uri.query.to_s == ''
+                      oauth_params_str
+                    else
+                      uri.query + '&' + oauth_params_str
+                    end
         path = uri.to_s
       end
 
